==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TokenCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.TokenCertificateName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of a certificate used for authenticating a token.
 * @property encodedPemCertificate Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
 * @property expiry The expiry datetime of the certificate.
 * @property name
 * @property thumbprint The thumbprint of the certificate.
 */
public data class TokenCertificateArgs(
    public val encodedPemCertificate: Output<String>? = null,
    public val expiry: Output<String>? = null,
    public val name: Output<Either<String, TokenCertificateName>>? = null,
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs =
        com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs.builder()
            .encodedPemCertificate(encodedPemCertificate?.applyValue({ args0 -> args0 }))
            .expiry(expiry?.applyValue({ args0 -> args0 }))
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TokenCertificateArgs].
 */
@PulumiTagMarker
public class TokenCertificateArgsBuilder internal constructor() {
    private var encodedPemCertificate: Output<String>? = null

    private var expiry: Output<String>? = null

    private var name: Output<Either<String, TokenCertificateName>>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
     */
    @JvmName("naqvqhxfsxddifdw")
    public suspend fun encodedPemCertificate(`value`: Output<String>) {
        this.encodedPemCertificate = value
    }

    /**
     * @param value The expiry datetime of the certificate.
     */
    @JvmName("kfwujfdwvwxkogea")
    public suspend fun expiry(`value`: Output<String>) {
        this.expiry = value
    }

    /**
     * @param value
     */
    @JvmName("iawxxetvwwthjsym")
    public suspend fun name(`value`: Output<Either<String, TokenCertificateName>>) {
        this.name = value
    }

    /**
     * @param value The thumbprint of the certificate.
     */
    @JvmName("nuojlepglbqghvhk")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
     */
    @JvmName("mnliilpvulkxrvgf")
    public suspend fun encodedPemCertificate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encodedPemCertificate = mapped
    }

    /**
     * @param value The expiry datetime of the certificate.
     */
    @JvmName("qsohkqjgpnhorafr")
    public suspend fun expiry(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expiry = mapped
    }

    /**
     * @param value
     */
    @JvmName("cexmihmyejxasyhy")
    public suspend fun name(`value`: Either<String, TokenCertificateName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("lltiobsyxkapbgrv")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TokenCertificateName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("lsjnocdpltocmbcv")
    public fun name(`value`: TokenCertificateName) {
        val toBeMapped = Either.ofRight<String, TokenCertificateName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The thumbprint of the certificate.
     */
    @JvmName("plclhaopjtgvfbyf")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): TokenCertificateArgs = TokenCertificateArgs(
        encodedPemCertificate = encodedPemCertificate,
        expiry = expiry,
        name = name,
        thumbprint = thumbprint,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/TokenCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.TokenCertificateName
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of a certificate used for authenticating a token.
 * @property encodedPemCertificate Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
 * @property expiry The expiry datetime of the certificate.
 * @property name
 * @property thumbprint The thumbprint of the certificate.
 */
public data class TokenCertificateArgs(
    public val encodedPemCertificate: Output<String>? = null,
    public val expiry: Output<String>? = null,
    public val name: Output<Either<String, TokenCertificateName>>? = null,
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs =
        com.pulumi.azurenative.containerregistry.inputs.TokenCertificateArgs.builder()
            .encodedPemCertificate(encodedPemCertificate?.applyValue({ args0 -> args0 }))
            .expiry(expiry?.applyValue({ args0 -> args0 }))
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TokenCertificateArgs].
 */
@PulumiTagMarker
public class TokenCertificateArgsBuilder internal constructor() {
    private var encodedPemCertificate: Output<String>? = null

    private var expiry: Output<String>? = null

    private var name: Output<Either<String, TokenCertificateName>>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
     */
    @JvmName("lrvfjrsedyeplwru")
    public suspend fun encodedPemCertificate(`value`: Output<String>) {
        this.encodedPemCertificate = value
    }

    /**
     * @param value The expiry datetime of the certificate.
     */
    @JvmName("balhiaoedtchtdst")
    public suspend fun expiry(`value`: Output<String>) {
        this.expiry = value
    }

    /**
     * @param value
     */
    @JvmName("hksgglwqhcpvsyal")
    public suspend fun name(`value`: Output<Either<String, TokenCertificateName>>) {
        this.name = value
    }

    /**
     * @param value The thumbprint of the certificate.
     */
    @JvmName("mpcpmotwlaotuvyd")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value Base 64 encoded string of the public certificate1 in PEM format that will be used for authenticating the token.
     */
    @JvmName("qifaifimndaowqal")
    public suspend fun encodedPemCertificate(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encodedPemCertificate = mapped
    }

    /**
     * @param value The expiry datetime of the certificate.
     */
    @JvmName("khxqxssswknsster")
    public suspend fun expiry(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expiry = mapped
    }

    /**
     * @param value
     */
    @JvmName("vkslroknaffrffmr")
    public suspend fun name(`value`: Either<String, TokenCertificateName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("jgdpcmvgdunctreg")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TokenCertificateName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("amtjppkepqepojhc")
    public fun name(`value`: TokenCertificateName) {
        val toBeMapped = Either.ofRight<String, TokenCertificateName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The thumbprint of the certificate.
     */
    @JvmName("pikxhyaeyxvsvbbj")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): TokenCertificateArgs = TokenCertificateArgs(
        encodedPemCertificate = encodedPemCertificate,
        expiry = expiry,
        name = name,
        thumbprint = thumbprint,
    )
}
